==> apache-hyracks-0.3.4-source-release.zip: apache-hyracks-0.3.4/hyracks/hyracks-dataflow-common/src/test/java/org/apache/hyracks/dataflow/common/data/normalizers/IntegerNormalizedKeyComputerFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.hyracks.dataflow.common.data.normalizers;

import org.apache.hyracks.api.dataflow.value.INormalizedKeyComputer;
import org.apache.hyracks.data.std.api.IPointable;
import org.apache.hyracks.data.std.primitive.IntegerPointable;
import org.apache.hyracks.dataflow.common.utils.NormalizedKeyUtils;

public class IntegerNormalizedKeyComputerFactoryTest extends AbstractNormalizedKeyComputerFactoryTest {

    private final INormalizedKeyComputer normalizer =
            new IntegerNormalizedKeyComputerFactory().createNormalizedKeyComputer();

    @Override
    protected IPointable getLargePositive() {
        return getIntPointable(Integer.MAX_VALUE - 1);
    }

    @Override
    protected IPointable getSmallPositive() {
        return getIntPointable(1);
    }

    @Override
    protected IPointable getLargeNegative() {
        return getIntPointable(-1);

    }

    @Override
    protected IPointable getSmallNegative() {
        return getIntPointable(Integer.MIN_VALUE + 1);
    }

    private IPointable getIntPointable(int value) {
        IntegerPointable pointable = (IntegerPointable) IntegerPointable.FACTORY.createPointable();
        pointable.set(new byte[Integer.BYTES], 0, Integer.BYTES);
        pointable.setInteger(value);
        return pointable;
    }

    @Override
    protected int[] normalize(IPointable value) {
        int[] keys = NormalizedKeyUtils.createNormalizedKeyArray(normalizer);
        normalizer.normalize(value.getByteArray(), value.getStartOffset(), value.getLength(), keys, 0);
        return keys;
    }

}

==> apache-hyracks-0.3.9-source-release.zip: apache-hyracks-0.3.9/hyracks/hyracks-dataflow-common/src/test/java/org/apache/hyracks/dataflow/common/data/normalizers/IntegerNormalizedKeyComputerFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.hyracks.dataflow.common.data.normalizers;

import org.apache.hyracks.api.dataflow.value.INormalizedKeyComputer;
import org.apache.hyracks.data.std.api.IPointable;
import org.apache.hyracks.data.std.primitive.IntegerPointable;
import org.apache.hyracks.dataflow.common.utils.NormalizedKeyUtils;

public class IntegerNormalizedKeyComputerFactoryTest extends AbstractNormalizedKeyComputerFactoryTest {

    private final INormalizedKeyComputer normalizer =
            new IntegerNormalizedKeyComputerFactory().createNormalizedKeyComputer();

    @Override
    protected IPointable getLargePositive() {
        return getIntPointable(Integer.MAX_VALUE - 1);
    }

    @Override
    protected IPointable getSmallPositive() {
        return getIntPointable(1);
    }

    @Override
    protected IPointable getLargeNegative() {
        return getIntPointable(-1);

    }

    @Override
    protected IPointable getSmallNegative() {
        return getIntPointable(Integer.MIN_VALUE + 1);
    }

    private IPointable getIntPointable(int value) {
        IntegerPointable pointable = IntegerPointable.FACTORY.createPointable();
        pointable.set(new byte[Integer.BYTES], 0, Integer.BYTES);
        pointable.setInteger(value);
        return pointable;
    }

    @Override
    protected int[] normalize(IPointable value) {
        int[] keys = NormalizedKeyUtils.createNormalizedKeyArray(normalizer);
        normalizer.normalize(value.getByteArray(), value.getStartOffset(), value.getLength(), keys, 0);
        return keys;
    }

}
